@@ -30,17 +30,20 @@ following criteria:
 
 =over 4
 
-=item C<text> or C<varchar> fields
+=item C<text>, C<char> or C<varchar> fields
 
-Create C<field>_contains and C<field>_lacks arguments.
+Create C<field>_contains and C<field>_lacks arguments
 
 =item C<date>, or C<timestamp> fields
 
-Create C<field>_before and C<field>_after ar
+Create C<field>_before, C<field>_after, C<field>_since and
+C<field>_until arguments.
 
-=item integer fields
+=item C<integer>, C<float>, C<double>, C<decimal> or C<numeric> fields
 
-Generate C<field>_lt and C<field>_gt arguments
+Generate C<field>_lt, C<field>_gt, C<field>_le and C<field>_ge arguments, as
+well as a C<field>_dwim field that accepts a prefixed comparison operator in
+the search value, such as C<< >100 >> and C<< !100 >>.
 
 =back
 
@@ -64,8 +67,24 @@ sub arguments {
 
         if($info->{valid_values}) {
             my $valid_values = $info->{valid_values};
-            $valid_values = [$valid_values] unless ref($valid_values) eq 'ARRAY';
-            unshift @$valid_values, "";
+
+            local $@;
+            $info->{valid_values} = $valid_values = (eval { [ @$valid_values ] } || [$valid_values]);
+
+            # For radio display, display an "any" label as empty choices looks weird
+            if (lc $info->{render_as} eq 'radio') {
+                if (@$valid_values > 1) {
+                    unshift @$valid_values, { display => _("(any)"), value => '' };
+                    $info->{default_value} ||= '';
+                }
+                else {
+                    # We've got only one choice anyway...
+                    $info->{default_value} ||= $valid_values->[0];
+                }
+            }
+            else {
+                unshift @$valid_values, "";
+            }
         }
 
         if(lc $info->{'render_as'} eq 'password') {
@@ -85,23 +104,31 @@ sub arguments {
         # Magic _id refers_to columns
         next if($field =~ /^(.*)_id$/ && $self->record->column($1));
 
-        if($column->type =~ /^(?:text|varchar)/i) {
+        my $label = $info->{label} || $field;
+        $args->{"${field}_not"} = { %$info, label => _("%1 is not", $label) };
+        my $type = lc($column->type);
+        if($type =~ /(?:text|char)/) {
             $info->{render_as} = 'text';
-            my $label = $info->{label} || $field;
-            $args->{"${field}_contains"} = {%$info, label => "$label contains"};
-            $args->{"${field}_lacks"} = {%$info, label => "$label lacks"};
-        } elsif($column->type =~ /(?:date|time)/) {
-            my $label = $info->{label} || $field;
-            $args->{"${field}_after"} = {%$info, label => "$label after"};
-            $args->{"${field}_before"} = {%$info, label => "$label before"};
-        } elsif(    $column->type =~ /(?:int)/
+            $args->{"${field}_contains"} = { %$info, label => _("%1 contains", $label) };
+            $args->{"${field}_lacks"} = { %$info, label => _("%1 lacks", $label) };
+        } elsif($type =~ /(?:date|time)/) {
+            $args->{"${field}_after"} = { %$info, label => _("%1 after", $label) };
+            $args->{"${field}_before"} = { %$info, label => _("%1 before", $label) };
+            $args->{"${field}_since"} = { %$info, label => _("%1 since", $label) };
+            $args->{"${field}_until"} = { %$info, label => _("%1 until", $label) };
+        } elsif(    $type =~ /(?:int|float|double|decimal|numeric)/
                 && !$column->refers_to) {
-            my $label = $info->{label} || $field;
-            $args->{"${field}_gt"} = {%$info, label => "$label greater than"};
-            $args->{"${field}_lt"} = {%$info, label => "$label less than"};
+            $args->{"${field}_gt"} = { %$info, label => _("%1 greater than", $label) };
+            $args->{"${field}_lt"} = { %$info, label => _("%1 less than", $label) };
+            $args->{"${field}_ge"} = { %$info, label => _("%1 greater or equal to", $label) };
+            $args->{"${field}_le"} = { %$info, label => _("%1 less or equal to", $label) };
+            $args->{"${field}_dwim"} = { %$info, hints => _('!=>< allowed') };
         }
     }
 
+    $args->{contains} = { type => 'text', label => _('Any field contains') };
+    $args->{lacks} = { type => 'text', label => _('No field contains') };
+
     return $self->_cached_arguments($args);
 }
 
@@ -126,22 +153,25 @@ sub take_action {
     $collection->unlimit;
 
     for my $field (grep {$self->has_argument($_)} $self->argument_names) {
+        next if $field eq 'contains';
         my $value = $self->argument_value($field);
         
         my $column = $self->record->column($field);
         my $op = undef;
         
-        if(!$column) {
+        if (!$column) {
             # If we don't have a column, this is a comparison or
             # substring search. Skip undef values for those, since
             # NULL makes no sense.
             next unless defined($value);
             next if $value =~ /^\s*$/;
 
-            if($field =~ m{^(.*)_([[:alpha:]]+)$}) {
+            if ($field =~ m{^(.*)_([[:alpha:]]+)$}) {
                 $field = $1;
                 $op = $2;
-                if($op eq 'contains') {
+                if($op eq 'not') {
+                    $op = '!=';
+                } elsif($op eq 'contains') {
                     $op = 'LIKE';
                     $value = "%$value%";
                 } elsif($op eq 'lacks') {
@@ -151,6 +181,17 @@ sub take_action {
                     $op = '>';
                 } elsif($op eq 'before' || $op eq 'lt') {
                     $op = '<';
+                } elsif($op eq 'since' || $op eq 'ge') {
+                    $op = '>=';
+                } elsif($op eq 'until' || $op eq 'le') {
+                    $op = '<=';
+                } elsif($op eq 'dwim') {
+                    $op = '=';
+                    if (defined($value) and $value =~ s/^\s*([<>!=]{1,2})\s*//) {
+                        $op = $1;
+                        $op = '!=' if $op eq '!';
+                        $op = '=' if $op eq '==';
+                    }
                 }
             } else {
                 next;
@@ -159,6 +200,13 @@ sub take_action {
         
         if(defined($value)) {
             next if $value =~ /^\s*$/;
+           
+            if ($op && $op =~ /^(?:!=|NOT LIKE)$/) {
+                $collection->limit( column   => $field, value    => $value, operator => $op || "=", entry_aggregator => 'OR', $op ? (case_sensitive => 0) : (),);
+                $collection->limit( column   => $field, value    => 'NULL', operator => 'IS');
+            } else { 
+
+            
             $collection->limit(
                 column   => $field,
                 value    => $value,
@@ -166,6 +214,10 @@ sub take_action {
                 entry_aggregator => 'AND',
                 $op ? (case_sensitive => 0) : (),
                );
+
+            } 
+
+
         } else {
             $collection->limit(
                 column   => $field,
@@ -175,6 +227,19 @@ sub take_action {
         }
     }
 
+    if($self->has_argument('contains')) {
+        my $any = $self->argument_value('contains');
+        for my $col ($self->record->columns) {
+            if($col->type =~ /(?:text|varchar)/) {
+                $collection->limit(column   => $col->name,
+                                   value    => "%$any%",
+                                   operator => 'LIKE',
+                                   entry_aggregator => 'OR',
+                                   subclause => 'contains');
+            }
+        }
+    }
+
     $self->result->content(search => $collection);
     $self->result->success;
 }
