@@ -11,6 +11,19 @@ C<Jifty::Bootstrap> is an abstract base class for your application's
 bootstrapping.  Use it to set up initial data in your database when
 your application is first installed.
 
+=head1 EXAMPLE
+
+ 
+ package MyApp::Bootstrap;
+ use base 'Jifty::Bootstrap';
+ 
+ sub run {
+     my $user = MyApp::CurrentUser->new( _bootstrap => 1);
+     my $modelclass = MyApp::Model::Thingy->new(current_user => $user);
+     $modelclass->create( name => 'Widget');
+ }; 
+ 
+ 
 =cut
 
 package Jifty::Bootstrap;
