@@ -13,7 +13,7 @@ render_as
 label
 hints
 placeholder
-length
+max_length
 mandatory
 
 =end properties
@@ -81,7 +81,7 @@ sub new {
     # a mapped argument, then do the mapping and mark the field as hidden.
     my ($key, $value) = Jifty::Request::Mapper->query_parameters($self->input_name, $self->current_value);
     if ($key ne $self->input_name) {
-        require Jifty::Web::Form::Field::Hidden;
+        Jifty::Util->require('Jifty::Web::Form::Field::Hidden');
         bless $self, "Jifty::Web::Form::Field::Hidden";
         $self->input_name($key);
         $self->default_value($value);
@@ -104,8 +104,8 @@ C<new>.  Subclasses should extend this list.
 
 =cut
 
-sub accessors { shift->SUPER::accessors(), qw(name label input_name type sticky sticky_value default_value action mandatory ajax_validates ajax_canonicalizes autocompleter preamble hints placeholder focus render_mode length _element_id); }
-__PACKAGE__->mk_accessors(qw(name _label _input_name type sticky sticky_value default_value _action mandatory ajax_validates ajax_canonicalizes autocompleter preamble hints placeholder focus render_mode length _element_id));
+sub accessors { shift->SUPER::accessors(), qw(name label input_name type sticky sticky_value default_value action mandatory ajax_validates ajax_canonicalizes autocompleter preamble hints placeholder focus render_mode max_length _element_id disable_autocomplete); }
+__PACKAGE__->mk_accessors(qw(name _label _input_name type sticky sticky_value default_value _action mandatory ajax_validates ajax_canonicalizes autocompleter preamble hints placeholder focus render_mode max_length _element_id disable_autocomplete));
 
 =head2 name [VALUE]
 
@@ -169,6 +169,10 @@ form, instead of waiting until submit.  Arguments will B<always> be
 canonicalized before the action is run, whether or not they also
 C<ajax_canonicalize>
 
+=head2 disable_autocomplete [VALUE]
+
+Gets or sets whether to disable _browser_ autocomplete for this field.
+
 =head2 preamble [VALUE]
 
 Gets or sets the preamble located in front of the field.
@@ -485,7 +489,8 @@ sub render_widget {
     $field .= qq! id="@{[ $self->element_id ]}"!;
     $field .= qq! value="@{[Jifty->web->escape($self->current_value)]}"! if defined $self->current_value;
     $field .= $self->_widget_class; 
-    $field .= qq! size="@{[ $self->length() ]}" maxlength="@{[ $self->length() ]}"! if ($self->length());
+    $field .= qq! size="@{[ $self->max_length() ]}" maxlength="@{[ $self->max_length() ]}"! if ($self->max_length());
+    $field .= qq! autocomplete="off"! if defined $self->disable_autocomplete;
     $field .= " " .$self->other_widget_properties;
     $field .= qq!  />\n!;
     Jifty->web->out($field);
@@ -541,7 +546,7 @@ sub render_value {
     my $field = '<span';
     $field .= qq! class="@{[ $self->classes ]}"> !;
     # XXX: force stringify the value because maketext is buggy with overloaded objects.
-    $field .= Jifty->web->escape(_("@{[$self->current_value]}")) if defined $self->current_value;
+    $field .= Jifty->web->escape("@{[$self->current_value]}") if defined $self->current_value;
     $field .= qq!</span>\n!;
     Jifty->web->out($field);
     return '';
@@ -706,4 +711,21 @@ qq!<span class="canonicalization_note @{[$self->classes]}" id="@{[$self->action-
     return '';
 }
 
+
+=for private
+
+=head2 length
+
+# Deprecated API
+
+
+=cut
+
+sub length {
+    my $self = shift;
+    Carp::carp("->length is deprecated; use ->max_length instead");
+    $self->max_length(@_);
+}
+
+
 1;
